==> openparty-0.1.0.tgz: package/locales/fr.js <==
{
  "OpenParty": "OpenParty",
  "Welcome on %s!": "Bienvenue sur %s !",
  "Please provide some credentials to access the lobby.": "Merci d'indiquer quelques informations avant de pouvoir rentrer.",
  "Username": "Pseudonyme",
  "Server password": "Mot de passe du serveur",
  "Enter!": "Entrer !",
  "Something went wrong...": "Quelque chose s'est mal passé...",
  "Connection with server has been interrupted. Don't panic ! We (probably) are trying to solve the problem.": "La connexion avec le serveur a été interrompue. Ne paniquez pas ! Nous sommes probablement en train de corriger le problème.",
  "Please check that you are correctly linked to internet and that the server is running.": "Veuillez vérifier que vous êtes correctement connecté à Internet, et que le serveur est actuellement en fonctionnement.",
  "Lobby": "Salle d'attente",
  "Welcome": "Bienvenue",
  "Open new room": "Ouvrir une nouvelle salle",
  "Name": "Nom",
  "Type": "Type",
  "Create": "Créer",
  "Ping": "Ping",
  "User": {
    "one": "Utilisateur",
    "other": "Utilisateurs"
  },
  "Room parameters": "Paramètres de la salle",
  "Hide": "Cacher",
  "Show": "Afficher",
  "Seats": "Places",
  "Leave": "Quitter",
  "Start!": "Commencer !",
  "No room is currently available :(": "Aucune salle n'est actuellement disponible :(",
  "By": "Par",
  "Join!": "Rejoindre !",
  "Player": {
    "one": "Joueur",
    "other": "Joueurs"
  },
  "Type a message here...": "Tapez un message içi...",
  "Username is too long.": "Le nom d'utilisateur est trop long.",
  "Bad Credentials": "Mauvais identifiants.",
  "Username is invalid.": "Le pseudonyme est invalide.",
  "Username is not available.": "Ce pseudonyme est déjà utilisé.",
  "About": "À propos",
  "Server status": "Statut du serveur",
  "Version:": "Version :",
  "Supported languages:": "Langages supportés :",
  "This website is powered by": "Ce site web est propulsé par",
  "an open-source framework for multiplayer chat games (GPL3).": "une solution open-source de jeux multijoueurs textuels (GPL3).",
  "Build your own server": "Créez votre propre serveur",
  "here!": "ici !",
  "and": "et",
  "Back": "Retour",
  "Gamemodes:": "Modes de jeu :",
  "Engine version:": "Version du moteur :",
  "You have to fill the room with several players before starting it.": "Vous devez remplir la salle avec différents joueurs avant de pouvoir la lancer.",
  "Password": "Mot de passe",
  "(no password)": "(aucun)",
  "Nobody waiting": "Personne attend",
  "person waiting": {
    "one": "personne attend",
    "other": "personnes attendent"
  },
  "nobody playing": "personne ne joue",
  "person playing": {
    "one": "personne joue",
    "other": "personnes jouent"
  },
  "One": "Une",
  "one": "une"
}

==> openparty-0.1.2.tgz: package/locales/fr.js <==
{
  "OpenParty": "OpenParty",
  "Welcome on %s!": "Bienvenue sur %s !",
  "Please provide some credentials to access the lobby.": "Merci d'indiquer quelques informations avant de pouvoir rentrer.",
  "Username": "Pseudonyme",
  "Server password": "Mot de passe du serveur",
  "Enter!": "Entrer !",
  "Something went wrong...": "Quelque chose s'est mal passé...",
  "Connection with server has been interrupted. Don't panic ! We (probably) are trying to solve the problem.": "La connexion avec le serveur a été interrompue. Ne paniquez pas ! Nous sommes probablement en train de corriger le problème.",
  "Please check that you are correctly linked to internet and that the server is running.": "Veuillez vérifier que vous êtes correctement connecté à Internet, et que le serveur est actuellement en fonctionnement.",
  "Lobby": "Salle d'attente",
  "Welcome": "Bienvenue",
  "Open new room": "Ouvrir une nouvelle salle",
  "Name": "Nom",
  "Type": "Type",
  "Create": "Créer",
  "Ping": "Ping",
  "User": {
    "one": "Utilisateur",
    "other": "Utilisateurs"
  },
  "Room parameters": "Paramètres de la salle",
  "Hide": "Cacher",
  "Show": "Afficher",
  "Seats": "Places",
  "Leave": "Quitter",
  "Start!": "Commencer !",
  "No room is currently available :(": "Aucune salle n'est actuellement disponible :(",
  "By": "Par",
  "Join!": "Rejoindre !",
  "Player": {
    "one": "Joueur",
    "other": "Joueurs"
  },
  "Type a message here...": "Tapez un message ici...",
  "Username is too long.": "Le nom d'utilisateur est trop long.",
  "Bad Credentials": "Mauvais identifiants.",
  "Username is invalid.": "Le pseudonyme est invalide.",
  "Username is not available.": "Ce pseudonyme est déjà utilisé.",
  "About": "À propos",
  "Server status": "Statut du serveur",
  "Version:": "Version :",
  "Supported languages:": "Langages supportés :",
  "This website is powered by": "Ce site web est propulsé par",
  "an open-source framework for multiplayer chat games (GPL3).": "une solution open-source de jeux multijoueurs textuels (GPL3).",
  "Build your own server": "Créez votre propre serveur",
  "here!": "ici !",
  "and": "et",
  "Back": "Retour",
  "Gamemodes:": "Modes de jeu :",
  "Engine version:": "Version du moteur :",
  "You have to fill the room with several players before starting it.": "Vous devez remplir la salle avec différents joueurs avant de pouvoir la lancer.",
  "Password": "Mot de passe",
  "(no password)": "(aucun)",
  "Nobody waiting": "Personne attend",
  "person waiting": {
    "one": "personne attend",
    "other": "personnes attendent"
  },
  "nobody playing": "personne ne joue",
  "person playing": {
    "one": "personne joue",
    "other": "personnes jouent"
  },
  "One": "Une",
  "one": "une"
}
